@@ -2,5 +2,6 @@ from .client import Client
 from .cheque import Cheque
 from .campaign import Campaign
 from .pos import POS
+from .operator import Operator
 
-__all__ = ['Client', 'Cheque', 'Campaign', 'POS']
+__all__ = ['Client', 'Cheque', 'Campaign', 'POS', 'Operator']
